@@ -31,7 +31,7 @@
 #define _GLIBCXX_CXX_CONFIG_H 1
 
 // The current version of the C++ library in compressed ISO date format.
-#define __GLIBCXX__ 20130531
+#define __GLIBCXX__ 20141219
 
 // Macros for various attributes.
 //   _GLIBCXX_PURE
@@ -84,6 +84,12 @@
 # define _GLIBCXX_DEPRECATED
 #endif
 
+// Macros for ABI tag attributes.
+#ifndef _GLIBCXX_ABI_TAG_CXX11
+# define _GLIBCXX_ABI_TAG_CXX11 __attribute ((__abi_tag__ ("cxx11")))
+#endif
+
+
 #if __cplusplus
 
 // Macro for constexpr, to support in mixed 03/0x mode.
@@ -530,7 +536,7 @@ namespace std
 #define _GLIBCXX_HAVE_EIDRM 1
 
 /* Define to 1 if you have the <endian.h> header file. */
-/* #undef _GLIBCXX_HAVE_ENDIAN_H */
+#define _GLIBCXX_HAVE_ENDIAN_H 1
 
 /* Define if ENODATA exists. */
 /* #undef _GLIBCXX_HAVE_ENODATA */
@@ -635,7 +641,7 @@ namespace std
 #define _GLIBCXX_HAVE_GETIPINFO 1
 
 /* Define if gets is available in <stdio.h>. */
-#define _GLIBCXX_HAVE_GETS 1
+/* #undef _GLIBCXX_HAVE_GETS */
 
 /* Define to 1 if you have the `hypot' function. */
 #define _GLIBCXX_HAVE_HYPOT 1
